tui

package
v1.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 8, 2026 License: MIT Imports: 28 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Run

func Run(cfg *config.Config) error

Run starts the Bubbletea TUI application

Types

type FilterMode

type FilterMode int

FilterMode represents different filter options

const (
	FilterAll FilterMode = iota
	FilterDirty
	FilterClean
)

type GitActionType

type GitActionType int
const (
	GitActionNone GitActionType = iota
	GitActionPullRebase
	GitActionSwitch
	GitActionCreateBranch
	GitActionMergeNoFF
)

type Model

type Model struct {
	// contains filtered or unexported fields
}

Model is the Bubbletea model for the TUI

func NewModel

func NewModel(cfg *config.Config) Model

NewModel creates a new TUI model

func (Model) GetFilterModeName

func (m Model) GetFilterModeName() string

GetFilterModeName returns the display name of current filter mode

func (Model) GetSelectedRepo

func (m Model) GetSelectedRepo() *model.Repo

GetSelectedRepo returns the currently selected repo

func (Model) GetSortModeName

func (m Model) GetSortModeName() string

GetSortModeName returns the display name of current sort mode

func (Model) Init

func (m Model) Init() tea.Cmd

Init initializes the model

func (Model) Update

func (m Model) Update(msg tea.Msg) (tea.Model, tea.Cmd)

Update handles messages and updates the model

func (Model) View

func (m Model) View() string

View renders the TUI

type SortMode

type SortMode int

SortMode represents different sorting options

const (
	SortByDirty SortMode = iota
	SortByName
	SortByBranch
	SortByLastCommit
)

type State

type State int

State represents the current UI state

const (
	StateLoading State = iota
	StateReady
	StateError
	StateSearching
	StateWorkspaceSwitch
	StateGitAction
	StateOpenRepo
	StateShortcuts
	StateCommandPalette
	StateActionLogs
)

Jump to